@@ -8,16 +8,6 @@ from dyatel.dyatel_sel.core.core_page import CorePage
 
 class MobilePage(CorePage):
 
-    def __init__(self, locator: str, locator_type: str, name: str):
-        """
-        Initializing of mobile page with appium driver
-
-        :param locator: anchor locator of page. Can be defined without locator_type
-        :param locator_type: specific locator type
-        :param name: name of page (will be attached to logs)
-        """
-        super().__init__(locator=locator, locator_type=locator_type, name=name)
-
     def swipe(self, start_x: int, start_y: int, end_x: int, end_y: int,
               duration: int = 0, sleep: Union[int, float] = 0) -> MobilePage:
         """
