@@ -1,18 +1,9 @@
 import io
-import logging
 from subprocess import Popen, PIPE, run
 
 from PIL import Image
 
 
-def set_logging_settings(level=logging.INFO):
-    logging.getLogger('WDM').setLevel(logging.ERROR)
-    logging.getLogger("urllib3").setLevel(logging.ERROR)
-    logging.basicConfig(level=level, format='[%(asctime)s][%(levelname)s][%(filename)s:%(lineno)s] %(message)s',
-                        datefmt='%Y-%m-%d %H:%M:%S')
-    return logging
-
-
 def resize_image(screenshot_binary, scale=3, img_format='JPEG'):
     img = Image.open(io.BytesIO(screenshot_binary))
     img = img.resize((img.width // scale, img.height // scale), Image.Resampling.LANCZOS)
@@ -42,6 +33,7 @@ def shell_command(cmd,  **kwargs):
 def cut_log_data(data: str, length=50) -> str:
     """
     Cut given data for reducing log length
+
     :param data: original data ~ 'very long string for typing. string endless continues'
     :param length: length to cut given data ~ 20
     :return: edited data ~ 'Type text: "very long string for >>> 36 characters"'
